//---------------------------------------------------------------------------------------------------------------------------------
//
//	File name: Ioctls.h
//
//	Description: IOCTL declarations for the 855WDTXP driver
//	Program name: WS855WDTXP.SYS
//	Program type: WindowsXP Device Driver
//
//	Creation date: 6/7/10
//
//	Author: Paul DeMetrotion
//
//	Revision History:
//    Date      Release Rev    Author    Description
//  --------    -----------    ------    --------------------------------------------------------------------------------
//  6/7/10        1.00          PD       Original release
//
//
//              ******************************** COPYRIGHT NOTICE AND DISCLAIMER ********************************
//	This source file is Copyright 2010 by WinSystems, Inc., Arlington, Texas. All rights reserved. This file is provided 'as-is'
//	and WinSystems makes no warranty as to usability of this code. Disclosure or use of this code except as provided below is
//	strictly prohibited. Refer to the WinSystems Hardware/Software Sales Agreement for other terms and conditions that may apply.
//---------------------------------------------------------------------------------------------------------------------------------

#ifndef IOCTLS_H
    #define IOCTLS_H

#ifndef CTL_CODE
    #pragma message("CTL_CODE undefined. Include winioctl.h or wdm.h")
#endif

typedef unsigned char BYTE;
typedef unsigned char* PBYTE;
typedef unsigned short WORD;
typedef unsigned short* PWORD;
typedef unsigned long DWORD;
typedef unsigned long* PDWORD;

// Define the type of device. This parameter can be no bigger than a WORD value. The values used by Microsoft are in the range of
// 0-32767 and the values between 32768-65535 are reserved for use by OEMs and IHVs
#define WDT_DEV_TYPE         32768

//---------------------------------------------------------------------------------------------------------------------------------
// IOCTL_READ_WDT
//
// code            IOCTL_READ_WDT
// cbin            Ignored
// cbout           [IN] Size of output data buffer, should be sizeof(BYTE)
// pCopyBuffer     [OUT] Pointer to a BYTE containing the data read
// info            [OUT] Number of output bytes put into the copy buffer
//---------------------------------------------------------------------------------------------------------------------------------

#define IOCTL_READ_WDT   CTL_CODE(WDT_DEV_TYPE, 0x800, METHOD_BUFFERED, FILE_ANY_ACCESS)

//---------------------------------------------------------------------------------------------------------------------------------
// IOCTL_WRITE_WDT
//
// code            IOCTL_WRITE_WDT
// cbin            [IN] Size of input data buffer, should be sizeof(BYTE)
// cbout           Ignored
// pCopyBuffer     [IN] Pointer to a BYTE containing the data to write
// info            Ignored
//---------------------------------------------------------------------------------------------------------------------------------

#define IOCTL_WRITE_WDT   CTL_CODE(WDT_DEV_TYPE, 0x801, METHOD_BUFFERED, FILE_ANY_ACCESS)

//---------------------------------------------------------------------------------------------------------------------------------
// IOCTL_ENABL_SEC
//
// code            IOCTL_ENABL_SEC
// cbin            Ignored
// cbout           Ignored
// pCopyBuffer     Ignored
// info            Ignored
//---------------------------------------------------------------------------------------------------------------------------------

#define IOCTL_ENABL_SEC   CTL_CODE(WDT_DEV_TYPE, 0x802, METHOD_BUFFERED, FILE_ANY_ACCESS)

//---------------------------------------------------------------------------------------------------------------------------------
// IOCTL_ENABL_MIN
//
// code            IOCTL_ENABL_MIN
// cbin            Ignored
// cbout           Ignored
// pCopyBuffer     Ignored
// info            Ignored
//---------------------------------------------------------------------------------------------------------------------------------

#define IOCTL_ENABL_MIN   CTL_CODE(WDT_DEV_TYPE, 0x803, METHOD_BUFFERED, FILE_ANY_ACCESS)

#endif
